@@ -1,7 +1,6 @@
-from .window import getMainWindow, getWidgetById, isMainWindow
+from .window import getMainWindow, isMainWindow
 from .window import load
-#from .window import ui
-from .test import abc
+from .window import deleteWidgetAndChildren
 import logging
 #logging.basicConfig(level=logging.WARN, format='%(message)s')
 #logging.basicConfig(filename="log", filemode='a', level=logging.WARN, format="%(asctime)s:%(levelname)s:%(name)s:%(message)s", datefmt='%Y-%m-%d %H:%M:%S')
