@@ -4,12 +4,12 @@ from PyQt5.QtWidgets import QLabel, QApplication, QDoubleSpinBox, QWidget, QPush
 #from qtpy.QtDesigner import QExtensionFactory
 from PyQt5.QtDesigner import QExtensionFactory
 from PyQt5.QtCore import pyqtProperty as Property
-from ophyd.sim import det
 import inspect
 from itertools import dropwhile
 import textwrap
 from .CodeObject import CodeObject
 from functools import partial
+import time
 
 import logging
 logger = logging.getLogger(__name__)
@@ -17,12 +17,18 @@ logger.setLevel(logging.DEBUG)
 
 class CodeButton(QPushButton, CodeObject):
 	def __init__(self, parent=None):
-		self.parent = parent
 		QPushButton.__init__(self, parent)
 		CodeObject.__init__(self, parent)
 		self.clicked.connect(self.runCode)
-		#self._useThreading = True
-		self.threadType = "qthread"
+
+	@Property(bool, designable=True)
+	def runInThread(self):
+		return self._useThreading
+
+	@runInThread.setter
+	def runInThread(self, val):
+		self._useThreading = val
+
 
 	def default_code(self):
 
@@ -31,10 +37,4 @@ class CodeButton(QPushButton, CodeObject):
 		print(self.objectName()+" pressed...")
 		"""[1:]
 		return code_string
-
-	def runCode(self):
-		if self.threadpool.waitForDone(0):
-			CodeObject.runCode(self)
-		else:
-			logger.info("Thread still running for CodeButton")
 	
