@@ -2,7 +2,7 @@ from .REButton import REButton, Scan1DButton, parseField, RECustomPlan
 from .CodeButton import CodeButton
 from .TextUpdate import TextUpdate
 from .mplwidget import MplWidget
-from .Base import all_bss_widgets, BaseWidget
+from .Base import BaseWidget
 from .embedframe import EmbedFrame, CodeContainer, OpenWindowButton
 from .lineinput import LineInput
 from .databrowser import DataBrowser
